@@ -31,7 +31,10 @@ from reprounzip import signals
 from reprounzip.unpackers.common import UsageError
 
 
-__version__ = '1.0.11'
+__version__ = '1.0.13'
+
+
+logger = logging.getLogger('reprounzip')
 
 
 unpackers = {}
@@ -66,7 +69,7 @@ class RPUZArgumentParser(argparse.ArgumentParser):
 
 def usage_report(args):
     if bool(args.enable) == bool(args.disable):
-        logging.critical("What do you want to do?")
+        logger.critical("What do you want to do?")
         raise UsageError
     enable_usage_report(args.enable)
     sys.exit(0)
