@@ -42,11 +42,14 @@ from reprounzip.utils import unicode_, irange, iteritems, itervalues, \
     download_file
 
 
+logger = logging.getLogger('reprounzip')
+
+
 def installpkgs(args):
     """Installs the necessary packages on the current machine.
     """
     if not THIS_DISTRIBUTION:
-        logging.critical("Not running on Linux")
+        logger.critical("Not running on Linux")
         sys.exit(1)
 
     pack = args.pack[0]
@@ -58,7 +61,7 @@ def installpkgs(args):
     try:
         installer = select_installer(pack, runs)
     except CantFindInstaller as e:
-        logging.error("Couldn't select a package installer: %s", e)
+        logger.error("Couldn't select a package installer: %s", e)
 
     if args.summary:
         # Print out a list of packages with their status
@@ -83,12 +86,12 @@ def installpkgs(args):
             req = pkg.version
             real = pkgs[pkg.name][1]
             if real == PKG_NOT_INSTALLED:
-                logging.warning("package %s was not installed", pkg.name)
+                logger.warning("package %s was not installed", pkg.name)
             else:
-                logging.warning("version %s of %s was installed, instead of "
-                                "%s", real, pkg.name, req)
+                logger.warning("version %s of %s was installed, instead of "
+                               "%s", real, pkg.name, req)
         if r != 0:
-            logging.critical("Installer exited with %d", r)
+            logger.critical("Installer exited with %d", r)
             sys.exit(r)
 
 
@@ -102,17 +105,17 @@ def directory_create(args):
     an upload) and the configuration file is extracted.
     """
     if not args.pack:
-        logging.critical("setup needs the pack filename")
+        logger.critical("setup needs the pack filename")
         sys.exit(1)
 
     pack = Path(args.pack[0])
     target = Path(args.target[0])
     if target.exists():
-        logging.critical("Target directory exists")
+        logger.critical("Target directory exists")
         sys.exit(1)
 
     if not issubclass(DefaultAbstractPath, PosixPath):
-        logging.critical("Not unpacking on POSIX system")
+        logger.critical("Not unpacking on POSIX system")
         sys.exit(1)
 
     signals.pre_setup(target=target, pack=pack)
@@ -135,15 +138,15 @@ def directory_create(args):
             continue
         for f in pkg.files:
             if not Path(f.path).exists():
-                logging.error(
+                logger.error(
                     "Missing file %s (from package %s that wasn't packed) "
                     "on host, experiment will probably miss it.",
                     f, pkg.name)
                 missing_files = True
     if missing_files:
         record_usage(directory_missing_pkgs=True)
-        logging.error("Some packages are missing, you should probably install "
-                      "them.\nUse 'reprounzip installpkgs -h' for help")
+        logger.error("Some packages are missing, you should probably install "
+                     "them.\nUse 'reprounzip installpkgs -h' for help")
 
     root.mkdir()
     try:
@@ -157,7 +160,7 @@ def directory_create(args):
                 linkname = PosixPath(m.linkname)
                 if linkname.is_absolute:
                     m.linkname = join_root(root, PosixPath(m.linkname)).path
-        logging.info("Extracting files...")
+        logger.info("Extracting files...")
         rpz_pack.extract_data(root, members)
         rpz_pack.close()
 
@@ -165,7 +168,7 @@ def directory_create(args):
         input_files = [f.path for f in itervalues(config.inputs_outputs)
                        if f.read_runs]
         if input_files:
-            logging.info("Packing up original input files...")
+            logger.info("Packing up original input files...")
             inputtar = tarfile.open(str(target / 'inputs.tar.gz'), 'w:gz')
             for ifile in input_files:
                 filename = join_root(root, ifile)
@@ -263,8 +266,8 @@ def directory_run(args):
                         argv[i] = str(rp)
                         rewritten = True
             if rewritten:
-                logging.warning("Rewrote command-line as: %s",
-                                ' '.join(shell_escape(a) for a in argv))
+                logger.warning("Rewrote command-line as: %s",
+                               ' '.join(shell_escape(a) for a in argv))
         else:
             argv = cmdline
         cmd += ' '.join(shell_escape(a) for a in argv)
@@ -288,7 +291,7 @@ def directory_destroy(args):
     target = Path(args.target[0])
     metadata_read(target, 'directory')
 
-    logging.info("Removing directory %s...", target)
+    logger.info("Removing directory %s...", target)
     signals.pre_destroy(target=target)
     rmtree_fixed(target)
     signals.post_destroy(target=target)
@@ -300,13 +303,13 @@ def should_restore_owner(param):
     if os.getuid() != 0:
         if param is True:
             # Restoring the owner was explicitely requested
-            logging.critical("Not running as root, cannot restore files' "
-                             "owner/group as requested")
+            logger.critical("Not running as root, cannot restore files' "
+                            "owner/group as requested")
             sys.exit(1)
         elif param is None:
             # Nothing was requested
-            logging.warning("Not running as root, won't restore files' "
-                            "owner/group")
+            logger.warning("Not running as root, won't restore files' "
+                           "owner/group")
             ret = False
         else:
             # If False: skip warning
@@ -314,8 +317,8 @@ def should_restore_owner(param):
     else:
         if param is None:
             # Nothing was requested
-            logging.info("Running as root, we will restore files' "
-                         "owner/group")
+            logger.info("Running as root, we will restore files' "
+                        "owner/group")
             ret = True
         elif param is True:
             ret = True
@@ -332,12 +335,12 @@ def should_mount_magic_dirs(param):
     if os.getuid() != 0:
         if param is True:
             # Restoring the owner was explicitely requested
-            logging.critical("Not running as root, cannot mount /dev and "
-                             "/proc")
+            logger.critical("Not running as root, cannot mount /dev and "
+                            "/proc")
             sys.exit(1)
         elif param is None:
             # Nothing was requested
-            logging.warning("Not running as root, won't mount /dev and /proc")
+            logger.warning("Not running as root, won't mount /dev and /proc")
             ret = False
         else:
             # If False: skip warning
@@ -345,7 +348,7 @@ def should_mount_magic_dirs(param):
     else:
         if param is None:
             # Nothing was requested
-            logging.info("Running as root, will mount /dev and /proc")
+            logger.info("Running as root, will mount /dev and /proc")
             ret = True
         elif param is True:
             ret = True
@@ -366,17 +369,17 @@ def chroot_create(args):
     an upload) and the configuration file is extracted.
     """
     if not args.pack:
-        logging.critical("setup/create needs the pack filename")
+        logger.critical("setup/create needs the pack filename")
         sys.exit(1)
 
     pack = Path(args.pack[0])
     target = Path(args.target[0])
     if target.exists():
-        logging.critical("Target directory exists")
+        logger.critical("Target directory exists")
         sys.exit(1)
 
     if not issubclass(DefaultAbstractPath, PosixPath):
-        logging.critical("Not unpacking on POSIX system")
+        logger.critical("Not unpacking on POSIX system")
         sys.exit(1)
 
     signals.pre_setup(target=target, pack=pack)
@@ -401,17 +404,17 @@ def chroot_create(args):
         packages_not_packed = [pkg for pkg in packages if not pkg.packfiles]
         if packages_not_packed:
             record_usage(chroot_missing_pkgs=True)
-            logging.warning("According to configuration, some files were left "
-                            "out because they belong to the following "
-                            "packages:%s\nWill copy files from HOST SYSTEM",
-                            ''.join('\n    %s' % pkg
-                                    for pkg in packages_not_packed))
+            logger.warning("According to configuration, some files were left "
+                           "out because they belong to the following "
+                           "packages:%s\nWill copy files from HOST SYSTEM",
+                           ''.join('\n    %s' % pkg
+                                   for pkg in packages_not_packed))
             missing_files = False
             for pkg in packages_not_packed:
                 for f in pkg.files:
                     path = Path(f.path)
                     if not path.exists():
-                        logging.error(
+                        logger.error(
                             "Missing file %s (from package %s) on host, "
                             "experiment will probably miss it",
                             path, pkg.name)
@@ -440,7 +443,7 @@ def chroot_create(args):
             for m in members:
                 m.uid = uid
                 m.gid = gid
-        logging.info("Extracting files...")
+        logger.info("Extracting files...")
         rpz_pack.extract_data(root, members)
         rpz_pack.close()
 
@@ -455,7 +458,7 @@ def chroot_create(args):
         sh_path = join_root(root, Path('/bin/sh'))
         env_path = join_root(root, Path('/usr/bin/env'))
         if not sh_path.lexists() or not env_path.lexists():
-            logging.info("Setting up busybox...")
+            logger.info("Setting up busybox...")
             busybox_path = join_root(root, Path('/bin/busybox'))
             busybox_path.parent.mkdir(parents=True)
             with make_dir_writable(join_root(root, Path('/bin'))):
@@ -474,7 +477,7 @@ def chroot_create(args):
         input_files = [f.path for f in itervalues(config.inputs_outputs)
                        if f.read_runs]
         if input_files:
-            logging.info("Packing up original input files...")
+            logger.info("Packing up original input files...")
             inputtar = tarfile.open(str(target / 'inputs.tar.gz'), 'w:gz')
             for ifile in input_files:
                 filename = join_root(root, ifile)
@@ -498,18 +501,24 @@ def chroot_mount(args):
     target = Path(args.target[0])
     unpacked_info = metadata_read(target, 'chroot')
 
-    for m in ('/dev', '/dev/pts', '/proc'):
+    # Create proc mount
+    d = target / 'root/proc'
+    d.mkdir(parents=True)
+    subprocess.check_call(['mount', '-t', 'proc', 'none', str(d)])
+
+    # Bind /dev from host
+    for m in ('/dev', '/dev/pts'):
         d = join_root(target / 'root', Path(m))
         d.mkdir(parents=True)
-        logging.info("Mounting %s on %s...", m, d)
+        logger.info("Mounting %s on %s...", m, d)
         subprocess.check_call(['mount', '-o', 'bind', m, str(d)])
 
     unpacked_info['mounted'] = True
     metadata_write(target, unpacked_info, 'chroot')
 
-    logging.warning("The host's /dev and /proc have been mounted into the "
-                    "chroot. Do NOT remove the unpacked directory with "
-                    "rm -rf, it WILL WIPE the host's /dev directory.")
+    logger.warning("The host's /dev and /proc have been mounted into the "
+                   "chroot. Do NOT remove the unpacked directory with "
+                   "rm -rf, it WILL WIPE the host's /dev directory.")
 
 
 @target_must_exist
@@ -589,7 +598,7 @@ def chroot_unmount(target):
     for m in ('/dev', '/proc'):
         d = join_root(target / 'root', Path(m))
         if d.exists():
-            logging.info("Unmounting %s...", d)
+            logger.info("Unmounting %s...", d)
             # Unmounts recursively
             subprocess.check_call(
                 'grep %s /proc/mounts | '
@@ -611,7 +620,7 @@ def chroot_destroy_unmount(args):
     target = Path(args.target[0])
 
     if not chroot_unmount(target):
-        logging.critical("Magic directories were not mounted")
+        logger.critical("Magic directories were not mounted")
         sys.exit(1)
 
 
@@ -623,10 +632,10 @@ def chroot_destroy_dir(args):
     mounted = metadata_read(target, 'chroot').get('mounted', False)
 
     if mounted:
-        logging.critical("Magic directories might still be mounted")
+        logger.critical("Magic directories might still be mounted")
         sys.exit(1)
 
-    logging.info("Removing directory %s...", target)
+    logger.info("Removing directory %s...", target)
     signals.pre_destroy(target=target)
     rmtree_fixed(target)
     signals.post_destroy(target=target)
@@ -640,7 +649,7 @@ def chroot_destroy(args):
 
     chroot_unmount(target)
 
-    logging.info("Removing directory %s...", target)
+    logger.info("Removing directory %s...", target)
     signals.pre_destroy(target=target)
     rmtree_fixed(target)
     signals.post_destroy(target=target)
@@ -707,8 +716,8 @@ class LocalDownloader(FileDownloader):
 
         # Output to stdout
         if not remote_path.exists():
-            logging.critical("Can't get output file (doesn't exist): %s",
-                             remote_path)
+            logger.critical("Can't get output file (doesn't exist): %s",
+                            remote_path)
             return False
         with remote_path.open('rb') as fp:
             copyfile(fp, stdout_bytes)
@@ -719,8 +728,8 @@ class LocalDownloader(FileDownloader):
 
         # Copy
         if not remote_path.exists():
-            logging.critical("Can't get output file (doesn't exist): %s",
-                             remote_path)
+            logger.critical("Can't get output file (doesn't exist): %s",
+                            remote_path)
             return False
         remote_path.copyfile(local_path)
         remote_path.copymode(local_path)
